.full-width[data-v-50dd0ebe],.full-width[data-v-963727e8]{width:40vw}div.container[data-v-625e1ee4]{text-align:center}.input[data-v-625e1ee4]{width:50vw}.card-item[data-v-fac133d8]{margin:5px;background-color:rgb(250 250 250)}.columns div.drag[data-v-fac133d8]{display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-start;max-height:15vh;overflow:auto}.columns div.drag>div[data-v-fac133d8]{margin:2px}.keys div.drag[data-v-fac133d8]{min-height:5vh;overflow:auto}.keys div.drag>div[data-v-fac133d8]{margin-bottom:2px}.agg div.drag[data-v-fac133d8]{min-height:5vh;overflow:auto}.agg div.drag>div[data-v-fac133d8]{margin-bottom:2px}div.apply-btn[data-v-fac133d8]{width:200px;margin:0 auto}div.container[data-v-fac133d8]{display:flex;flex-direction:row;align-items:flex-start}div.container>div.columns[data-v-fac133d8]{flex-grow:0.5}div.container>div.keys[data-v-fac133d8]{flex-grow:0}div.container>div.agg[data-v-fac133d8]{flex-grow:0.5}code.context_wrapper[data-v-095220fe]{text-align:left}div.container[data-v-37cd6bc0]{text-align:center}.input[data-v-37cd6bc0]{width:50vw}div.pane[data-v-1841846c]{max-height:35vh;overflow:auto}code[data-v-02ffa1c1],code[data-v-22277705]{text-align:left}.ant-tag-close-icon[data-v-78d05249]{display:inline}code[data-v-78d05249]{overflow:auto}header.tabs_wrapper[data-v-3ea33a37]{max-width:90vw;margin-left:auto;margin-right:auto}main.table[data-v-3ea33a37]{min-height:50vh}div.v[data-v-3ea33a37]{margin:25px 0 0 15px;max-height:100vh;overflow:auto}div.container-h[data-v-3ea33a37]{display:flex;flex-direction:row}div.container-h>div.item-left[data-v-3ea33a37]{flex-grow:0;padding:0 auto;margin-right:10px;flex-shrink:0}div.container-h>div.item-right[data-v-3ea33a37]{flex-grow:1;overflow:auto}div.container-v[data-v-3ea33a37]{display:flex;flex-direction:column}div.container-v>div.item-top[data-v-3ea33a37]{flex-grow:0;padding:0 auto;margin-right:10px;flex-shrink:0}div.container-v>div.item-bottom[data-v-3ea33a37]{flex-grow:1;overflow:auto}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-align:center;color:#2c3e50;padding-left:0;padding-right:0;box-sizing:border-box}#app,.wrapper{margin-left:auto;margin-right:auto}.wrapper{width:95%;max-width:1841px}